import settings;

defaultpen(1);
bbox(white, Fill);

pen[] colours = {
  orange,
  deepblue,
  red,
  fuchsia,
  green,
  purple,
};

int SCALE = 5;
int PSCALE = 10 * SCALE;

int min_x = 1000000000;
int max_x = 0;

int n = stdin;
for (int i = 0; i < n; ++i) {
  int x0 = SCALE * (int) stdin;
  int x1 = SCALE * (int) stdin;
  real y0 = 0;
  real y1 = -min((x1 - x0) / (2 * (sqrt(5.0) - 1.0)), 1e6);

  filldraw(
      (x0, y0) -- (x1, y0) -- (x1, y1) -- (x0, y1) -- cycle,
      fillpen=colours[i % colours.length], // +opacity(0.75),
      drawpen=darkgrey);

  min_x = min(min_x, x0);
  max_x = max(max_x, x1);
}

// Line and ticks (if there are few enough to reasonably draw)
draw((min_x - SCALE/2, 0) -- (max_x + SCALE/2, 0));
if (max_x - min_x <= 1000 * SCALE) {
  for (int x = min_x; x <= max_x; x += SCALE) {
    if (x % (10 * SCALE) == 0) {
      draw((x, PSCALE/4) -- (x, 0), black);
    } else {
      draw((x, PSCALE/8) -- (x, 0), grey);
    }
  }
}

// Make the canvas pretty big if required.
size(min(10000, (max_x - min_x)*2));

real[] read_pegs() {
  if (eof(stdin)) {
    return new real[];
  }
  int n = stdin;
  real[] x = new real[n];
  for (int i = 0; i < n; ++i) {
    x[i] = ((real) stdin);
  }
  return x;
}

void add_pegs(real[] positions, pen fillpen, pen drawpen) {
  for (int i = 0; i < positions.length; ++i) {
    real x = SCALE * positions[i];
    real y = 0;
    filldraw(
        (x - PSCALE/12, y - PSCALE/3) --
        (x - PSCALE/12, y + PSCALE/2) --
        (x + PSCALE/12, y + PSCALE/2) --
        (x + PSCALE/12, y - PSCALE/3) -- cycle,
        fillpen=fillpen,
        drawpen=drawpen);
  }
}

add_pegs(read_pegs(), fillpen=white, drawpen=black);
add_pegs(read_pegs(), fillpen=brown, drawpen=white);

shipout(bbox(xmargin=5, white, Fill));
